@@ -58,15 +58,14 @@ export namespace EclipseChe {
   export const OPERATOR_IMAGE_NEXT_TAG = 'next'
 
   // Doc links
-  export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.15/'
-  export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.15/html/release_notes_and_known_issues/index'
+  export const DOC_LINK = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.16/'
+  export const DOC_LINK_RELEASE_NOTES = 'https://access.redhat.com/documentation/en-us/red_hat_openshift_dev_spaces/3.16/html/release_notes_and_known_issues/index'
   export const DOC_LINK_CONFIGURE_API_SERVER = 'https://kubernetes.io/docs/reference/access-authn-authz/authentication/#configuring-the-api-server'
 
   // Components
   export const CHE_SERVER = `${PRODUCT_NAME} Server`
   export const DASHBOARD = 'Dashboard'
   export const GATEWAY = 'Gateway'
-  export const DEVFILE_REGISTRY = 'Devfile Registry'
   export const PLUGIN_REGISTRY = 'Plugin Registry'
   export const CHE_OPERATOR = `${PRODUCT_NAME} Operator`
 
@@ -75,7 +74,6 @@ export namespace EclipseChe {
   export const CHE_SERVER_DEPLOYMENT_NAME = `${CHE_FLAVOR}`
   export const DASHBOARD_DEPLOYMENT_NAME = `${CHE_FLAVOR}-dashboard`
   export const GATEWAY_DEPLOYMENT_NAME = 'che-gateway'
-  export const DEVFILE_REGISTRY_DEPLOYMENT_NAME = 'devfile-registry'
   export const PLUGIN_REGISTRY_DEPLOYMENT_NAME = 'plugin-registry'
 
   // Selectors
@@ -84,7 +82,6 @@ export namespace EclipseChe {
 
   export const CHE_SERVER_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=${CHE_FLAVOR}`
   export const DASHBOARD_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=${CHE_FLAVOR}-dashboard`
-  export const DEVFILE_REGISTRY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=devfile-registry`
   export const PLUGIN_REGISTRY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=plugin-registry`
   export const GATEWAY_SELECTOR = `app.kubernetes.io/name=${CHE_FLAVOR},app.kubernetes.io/component=che-gateway`
 }
